@@ -17,11 +17,22 @@ class Redis(object):
         self.__dict__ = self.__state
         if '_pool' not in self.__dict__:
             config = Config()
+
+            # set defaults
+            db = 0
+            host = 'localhost'
+            port = 6379
+            max_connections = 10
+
+            if 'redis' in config:
+                db = config.redis.get('db', db)
+                host = config.redis.get('host', host)
+                port = config.redis.get('port', port)
+                max_connections = config.redis.get('max_poolsize', max_connections)
+
             # we only need one pool per app
-            self._pool = redis.ConnectionPool(db=config.redis.get('db', 0),
-                                              host=config.redis.get('host', 'localhost'),
-                                              port=config.redis.get('port', 6379),
-                                              max_connections=config.redis.get('max_poolsize', 10))
+            self._pool = redis.ConnectionPool(db=db, host=host, port=port,
+                                              max_connections=max_connections)
 
         # each object required its own connection so that we can close
         # it after each request without affecting other requests
